# -*- coding: utf-8 -*-
# Generated by Django 1.9.12 on 2017-07-10 15:56
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oscar_webpay', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='webpaytransaction',
            name='error_auth_code',
            field=models.CharField(choices=[(b'TSY', 'Successful transaction'), (b'TSN', 'Failed transaction'), (b'TO', 'Time limit exceeded'), (b'ABO', 'Transaction aborted by card holder'), (b'U3', 'Authentication internal error')], max_length=3, null=True, verbose_name='Error code'),
        ),
    ]



from oscar_webpay.libwebpay.webpay import Webpay
from oscar_webpay.certificates import cert_normal
from oscar_webpay.libwebpay.configuration import Configuration

from oscar_webpay.oscar_webpay_settings import oscar_webpay_settings
from oscar_webpay.exceptions import \
    AuthenticationError, \
    FailedTransaction, \
    AbortedTransactionByCardHolder, \
    TimeLimitExceeded, \
    U3Exception

from django.core.urlresolvers import reverse


def get_webpay_conf():
    certificate = cert_normal.certDictionary.dictionaryCert()
    configuration = Configuration()
    configuration.setEnvironment(certificate['environment'])
    configuration.setCommerceCode(certificate['commerce_code'])
    configuration.setPrivateKey(certificate['private_key'])
    configuration.setPublicCert(certificate['public_cert'])
    configuration.setWebpayCert(certificate['webpay_cert'])
    return configuration


class WebPayClient(object):

    def __init__(self):
        self.webpay = Webpay(get_webpay_conf())

    def get_webpay_client(self, order_number, total, return_url_name, final_url_name):
        amount = total
        buy_order = order_number
        session_id = None

        final_url = '{}:{}{}'.format(
            oscar_webpay_settings.WEBPAY_RETURN_ADDRESS,
            oscar_webpay_settings.WEBPAY_RETURN_PORT,
            reverse(final_url_name)
        )

        return_url = '{}:{}{}'.format(
            oscar_webpay_settings.WEBPAY_RETURN_ADDRESS,
            oscar_webpay_settings.WEBPAY_RETURN_PORT,
            reverse(return_url_name)
        )

        initTransactionOutput = self.webpay.getNormalTransaction().initTransaction(
            amount, buy_order, session_id, return_url, final_url)
        return initTransactionOutput

    def confirm_transaction(self, token):
        result = self.webpay.getNormalTransaction().getTransaction(token)

        if result.VCI == 'TSY':
            # Successful transaction.
            pass

        if result.VCI == 'TSN':
            raise FailedTransaction(result)

        if result.VCI == 'TO':
            # Time limit exceeded.
            raise TimeLimitExceeded

        if result.VCI == 'ABO':
            # Failed transaction.
            raise AbortedTransactionByCardHolder

        if result.VCI == 'U3':
            # Internal authentication error.
            raise U3Exception

        return result

    def acknowledge_transaction(self, token):
        result = self.webpay.getNormalTransaction().acknowledgeTransaction(token)
        return result



# -*- coding: utf-8 -*-
# Generated by Django 1.9.12 on 2017-07-31 22:20
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oscar_webpay', '0004_webpaytransaction_result_auth_code'),
    ]

    operations = [
        migrations.AlterField(
            model_name='webpaytransaction',
            name='error_auth_code',
            field=models.CharField(choices=[(b'TSY', 'Successful authentication'), (b'TSN', 'Failed authentication'), (b'TO', 'Time limit exceeded'), (b'ABO', 'Transaction aborted by card holder'), (b'U3', 'Authentication internal error')], max_length=3, null=True, verbose_name='Error code'),
        ),
        migrations.AlterField(
            model_name='webpaytransaction',
            name='result_auth_code',
            field=models.IntegerField(blank=True, choices=[(0, 'Approved transaction'), (-1, 'Transaction rejected.'), (-2, 'Transaction submitted again.'), (-3, 'Error in transaction.'), (-4, 'Transaction rejected.'), (-5, 'Rejection by error of rate.'), (-6, 'Exceeds monthly maximum quota.'), (-7, 'Exceeds daily limit per transaction.'), (-8, 'Unauthorized item.')], null=True, verbose_name='Result authentication code'),
        ),
    ]
